Perform clustering of count data using the MMPCA model.
mmpca_clust(
dtm,
Q,
K,
model = NULL,
Yinit = "random",
method = "BBCVEM",
init.beta = "lda",
keep = 1L,
max.epochs = 10L,
verbose = 1L,
nruns = 1L,
mc.cores = max(1, (detectCores() - 1))
)an NxV DocumentTermMatrix with term-frequency
weighting.
The number of clusters
The number of topics (latent space dimension)
Parameter for the initialization of Y. It can be either:
a string or a function specifying the initialization
procedure. It should be one of ('random', 'kmeans_lda'). See
benchmarks-functions functions for more details.
A vector of length N with Q modalities, specifying the initialization clustering.
The clustering algorithm to be used. Only "BBCVEM" is available : it corresponds to the branch and bound C-VEM of the original article.
Parameter for the initialization of the matrix beta. It can be either:
a string specifying the initialization
procedure. It should be one of ('random', 'lda'). See
initializeBeta() for more details.
A KxV matrix with each row summing to 1.
The evolution of the bound is tracked every keep iteration
Specifies the maximum number of pass allowed on the whole dataset.
verbosity level
number of runs of the algorithm (default to 1) : the run achieving the best evidence lower bound is selected.
The number of CPUs to use when fitting in parallel the different models (only for non-Windows platforms). Default is the number of available cores minus 1.
An object of class "'>mmpcaClust" containing the
fitted model.